# Terminals
Python Class used on Basic Operations on Image as Getting red Component of Image, or green component ,it gets dx,dy,dxx,dyy of each pixel of image too ,and many other operations 

# when to USE :
You could use it in your python Image processing project
to do basic Calculations on Image pixels (it traverse,and make the operation on Image pixel by pixel)


# prerequest : 

  Python 2.6 or higher
  and Libraries :   
    deap 
    operator
    math
    random
    cv2
    numpy
    
# How To use 
  1 - just Download the File 
  2 - put it besides your Python Code
  3 import it as Python Class , and use its Functions
  
# Author 

  please , when use Refere To Amr A. El LAtief amrabdellatief1@gmail.com

  feedback ,and Sugestions : amrabdellatief1@gmail.com 

# Contributer List 
   please Contripute and Share , To be Added To this Honor List  
   
